/*
 * Code for class SHARED_INSTANTIATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sh656.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SHARED_INSTANTIATOR}.instantiator */
static EIF_REFERENCE F757_10282_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	

	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (10282);
#define Result RTOSR(10282)
	RTOC_NEW(Result);
	Result = *(EIF_REFERENCE *)(RTCV(RTOSCF(10214,F744_10214, (Current))) + _REFACS_83_);
	RTOSE (10282);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F757_10282 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(10282,F757_10282_body,(Current));
}

void EIF_Minit656 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
